"""
GUI (Graphical User Interface) modules for OPC UA Data Diode

This module contains both Tkinter-based graphical interfaces
and ncurses-based terminal interfaces.
"""

__all__ = [
    "sender_gui",
    "receiver_gui",
    "sender_gui_ncurses",
    "receiver_gui_ncurses"
]
