"""
OPC UA Data Diode - Secure one-way data replication for OPC UA servers

Copyright (C) 2026 Alin-Adrian Anton <alin.anton@upt.ro>

This program is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program.  If not, see <https://www.gnu.org/licenses/>.
"""

__version__ = "1.0.3"
__author__ = "Alin-Adrian Anton"
__email__ = "alin.anton@upt.ro"
__license__ = "GPL-3.0-or-later"

__all__ = ["cli", "gui"]
