"""
CLI (Command Line Interface) modules for OPC UA Data Diode

This module contains the headless sender and receiver scripts
for automated deployment and operation.
"""

__all__ = ["sender_auto", "receiver_auto"]
